:mod:`Payment`
=============

Models
------
.. automodule:: lfs.payment.models

   .. autoclass:: PaymentMethod
   .. autoclass:: PaymentMethodPrice
      :members:

Utils 
------   
.. automodule:: lfs.payment.utils

   .. autofunction:: get_valid_payment_methods
   .. autofunction:: get_default_payment_method
   .. autofunction:: get_selected_payment_method
   .. autofunction:: get_payment_costs
   .. autofunction:: process_payment